@@ -1,6 +1,7 @@
-#!/usr/bin/perl
-
 package Devel::Events::Filter::RemoveFields;
+# vim: set ts=2 sw=2 noet nolist :
+# ABSTRACT: Remove certain fields from events
+our $VERSION = '0.10';
 use Moose;
 
 with qw/Devel::Events::Filter/;
@@ -43,10 +44,16 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::Events::Filter::RemoveFields - Remove certain fields from events
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
 	use Devel::Events::Filter::RemoveFields;
@@ -87,6 +94,20 @@ Removes the fields specified in C<fields> from the event data.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Events>
+(or L<bug-Devel-Events@rt.cpan.org|mailto:bug-Devel-Events@rt.cpan.org>).
+
+=head1 AUTHOR
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2007 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
